#!/usr/bin/env bash
set -e

efi_mnt="/boot/efi"
boot_order_file="${efi_mnt}/EFI/BOOT/HwBootOrder.ini"

next_boot=$1
if [[ -z $next_boot ]]; then
    echo "Usage: $0 next_boot"
    echo "Arguments:"
    echo "next_boot    choices:hd, pxe"
    exit 1
fi

if [[ $(id -u) -ne 0 ]]; then
    echo "Root permission required"
    exit 1
fi
efi_readonly=false
if mountpoint -q $efi_mnt && [[ ! -w $efi_mnt ]]; then
    echo "$efi_mnt is readonly"
    efi_readonly=true
    mount -o remount,rw $efi_mnt
fi


case $next_boot in
    hd|HD)
          echo HwBootOrder=0123 > ${boot_order_file}
          ;;
    pxe|PXE)
          echo HwBootOrder=2013 > ${boot_order_file}
          ;;
    *)
          echo "Error argument $next_boot, only hd or pxe is supported"
          exit 1
esac

if $efi_readonly; then
    echo "restore $efi_mnt to readonly"
    mount -o remount,ro $efi_mnt
fi

echo "set next order to $next_boot is done"
echo "print the content of ${boot_order_file}"
cat ${boot_order_file}
